# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_log_pb2 as admin_dot_v1_dot_integration__log__pb2


class LogsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateIntegrationLogs = channel.unary_unary(
                '/admin.v1.LogsService/CreateIntegrationLogs',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsResponse.FromString,
                )
        self.GetIntegrationLogs = channel.unary_unary(
                '/admin.v1.LogsService/GetIntegrationLogs',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsResponse.FromString,
                )
        self.GetIntegrationLogById = channel.unary_unary(
                '/admin.v1.LogsService/GetIntegrationLogById',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdResponse.FromString,
                )
        self.DeleteIntegrationLogs = channel.unary_unary(
                '/admin.v1.LogsService/DeleteIntegrationLogs',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsResponse.FromString,
                )
        self.CreateLogsLinkItem = channel.unary_unary(
                '/admin.v1.LogsService/CreateLogsLinkItem',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemResponse.FromString,
                )
        self.GetLogsLinkItemById = channel.unary_unary(
                '/admin.v1.LogsService/GetLogsLinkItemById',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdResponse.FromString,
                )
        self.DeleteLogsLinkItem = channel.unary_unary(
                '/admin.v1.LogsService/DeleteLogsLinkItem',
                request_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemResponse.FromString,
                )


class LogsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateIntegrationLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationLogById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegrationLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLogsLinkItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogsLinkItemById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLogsLinkItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LogsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateIntegrationLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegrationLogs,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsResponse.SerializeToString,
            ),
            'GetIntegrationLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationLogs,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsResponse.SerializeToString,
            ),
            'GetIntegrationLogById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationLogById,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdResponse.SerializeToString,
            ),
            'DeleteIntegrationLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegrationLogs,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsResponse.SerializeToString,
            ),
            'CreateLogsLinkItem': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLogsLinkItem,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemResponse.SerializeToString,
            ),
            'GetLogsLinkItemById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogsLinkItemById,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdResponse.SerializeToString,
            ),
            'DeleteLogsLinkItem': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLogsLinkItem,
                    request_deserializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.LogsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LogsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateIntegrationLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/CreateIntegrationLogs',
            admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.CreateIntegrationLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/GetIntegrationLogs',
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationLogById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/GetIntegrationLogById',
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.GetIntegrationLogByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegrationLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/DeleteIntegrationLogs',
            admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.DeleteIntegrationLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateLogsLinkItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/CreateLogsLinkItem',
            admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.CreateLogsLinkItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogsLinkItemById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/GetLogsLinkItemById',
            admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.GetLogsLinkItemByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLogsLinkItem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.LogsService/DeleteLogsLinkItem',
            admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemRequest.SerializeToString,
            admin_dot_v1_dot_integration__log__pb2.DeleteLogsLinkItemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_external_api_pb2 as admin_dot_v1_dot_integration__external__api__pb2


class ExternalApiServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateExternalApiIntegration = channel.unary_unary(
                '/admin.v1.ExternalApiService/CreateExternalApiIntegration',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationResponse.FromString,
                )
        self.GetExternalApiIntegration = channel.unary_unary(
                '/admin.v1.ExternalApiService/GetExternalApiIntegration',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationResponse.FromString,
                )
        self.DeleteExternalApiIntegration = channel.unary_unary(
                '/admin.v1.ExternalApiService/DeleteExternalApiIntegration',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationResponse.FromString,
                )
        self.GetExternalApiIntegrations = channel.unary_unary(
                '/admin.v1.ExternalApiService/GetExternalApiIntegrations',
                request_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsResponse.FromString,
                )


class ExternalApiServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateExternalApiIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExternalApiIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteExternalApiIntegration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExternalApiIntegrations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExternalApiServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateExternalApiIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateExternalApiIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationResponse.SerializeToString,
            ),
            'GetExternalApiIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExternalApiIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationResponse.SerializeToString,
            ),
            'DeleteExternalApiIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteExternalApiIntegration,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationResponse.SerializeToString,
            ),
            'GetExternalApiIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExternalApiIntegrations,
                    request_deserializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.ExternalApiService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExternalApiService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateExternalApiIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/CreateExternalApiIntegration',
            admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.CreateExternalApiIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExternalApiIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/GetExternalApiIntegration',
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteExternalApiIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/DeleteExternalApiIntegration',
            admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.DeleteExternalApiIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExternalApiIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.ExternalApiService/GetExternalApiIntegrations',
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsRequest.SerializeToString,
            admin_dot_v1_dot_integration__external__api__pb2.GetExternalApiIntegrationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SidecarLink(_message.Message):
    __slots__ = ["id", "sidecar_id", "datastore_id", "port", "datastore_name"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SIDECAR_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    id: str
    sidecar_id: str
    datastore_id: str
    port: int
    datastore_name: str
    def __init__(self, id: _Optional[str] = ..., sidecar_id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., port: _Optional[int] = ..., datastore_name: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Domain(_message.Message):
    __slots__ = ["id", "name", "description", "owners", "excluded_paths", "included_paths"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    INCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    owners: _containers.RepeatedCompositeFieldContainer[Owner]
    excluded_paths: _containers.RepeatedScalarFieldContainer[str]
    included_paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., owners: _Optional[_Iterable[_Union[Owner, _Mapping]]] = ..., excluded_paths: _Optional[_Iterable[str]] = ..., included_paths: _Optional[_Iterable[str]] = ...) -> None: ...

class Owner(_message.Message):
    __slots__ = ["object_type", "object_id"]
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_ID_FIELD_NUMBER: _ClassVar[int]
    object_type: str
    object_id: str
    def __init__(self, object_type: _Optional[str] = ..., object_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_app.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import app_pb2 as admin_dot_v1_dot_types_dot_v1_dot_app__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_app.proto\x12\x08\x61\x64min.v1\x1a\x1b\x61\x64min/v1/types/v1/app.proto\"\x1f\n\x1dRefreshIntegrationAppsRequest\" \n\x1eRefreshIntegrationAppsResponse\"\x1b\n\x19GetIntegrationAppsRequest\"c\n\x1aGetIntegrationAppsResponse\x12\x45\n\x0cintegrations\x18\x01 \x03(\x0b\x32!.admin.v1.types.v1.IntegrationAppR\x0cintegrations\"+\n\x19GetIntegrationByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"a\n\x1aGetIntegrationByIdResponse\x12\x43\n\x0bintegration\x18\x01 \x01(\x0b\x32!.admin.v1.types.v1.IntegrationAppR\x0bintegration\"\xd1\x02\n\x1b\x43reateIntegrationAppRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12+\n\x11metabase_hostname\x18\x03 \x01(\tR\x10metabaseHostname\x12+\n\x11metabase_username\x18\x04 \x01(\tR\x10metabaseUsername\x12+\n\x11metabase_password\x18\x05 \x01(\tR\x10metabasePassword\x12)\n\x11linked_db_user_id\x18\x06 \x01(\tR\x0elinkedDbUserId\x12(\n\x10\x66ivetran_api_key\x18\x07 \x01(\tR\x0e\x66ivetranApiKey\x12.\n\x13\x66ivetran_api_secret\x18\x08 \x01(\tR\x11\x66ivetranApiSecret\"c\n\x1c\x43reateIntegrationAppResponse\x12\x43\n\x0bintegration\x18\x01 \x01(\x0b\x32!.admin.v1.types.v1.IntegrationAppR\x0bintegration\"-\n\x1b\x44\x65leteIntegrationAppRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1e\n\x1c\x44\x65leteIntegrationAppResponse2\x89\x04\n\nAppService\x12k\n\x16RefreshIntegrationApps\x12\'.admin.v1.RefreshIntegrationAppsRequest\x1a(.admin.v1.RefreshIntegrationAppsResponse\x12_\n\x12GetIntegrationApps\x12#.admin.v1.GetIntegrationAppsRequest\x1a$.admin.v1.GetIntegrationAppsResponse\x12_\n\x12GetIntegrationById\x12#.admin.v1.GetIntegrationByIdRequest\x1a$.admin.v1.GetIntegrationByIdResponse\x12\x65\n\x14\x43reateIntegrationApp\x12%.admin.v1.CreateIntegrationAppRequest\x1a&.admin.v1.CreateIntegrationAppResponse\x12\x65\n\x14\x44\x65leteIntegrationApp\x12%.admin.v1.DeleteIntegrationAppRequest\x1a&.admin.v1.DeleteIntegrationAppResponseB\xae\x01\n\x0c\x63om.admin.v1B\x13IntegrationAppProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_app_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationAppProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_REFRESHINTEGRATIONAPPSREQUEST']._serialized_start=73
  _globals['_REFRESHINTEGRATIONAPPSREQUEST']._serialized_end=104
  _globals['_REFRESHINTEGRATIONAPPSRESPONSE']._serialized_start=106
  _globals['_REFRESHINTEGRATIONAPPSRESPONSE']._serialized_end=138
  _globals['_GETINTEGRATIONAPPSREQUEST']._serialized_start=140
  _globals['_GETINTEGRATIONAPPSREQUEST']._serialized_end=167
  _globals['_GETINTEGRATIONAPPSRESPONSE']._serialized_start=169
  _globals['_GETINTEGRATIONAPPSRESPONSE']._serialized_end=268
  _globals['_GETINTEGRATIONBYIDREQUEST']._serialized_start=270
  _globals['_GETINTEGRATIONBYIDREQUEST']._serialized_end=313
  _globals['_GETINTEGRATIONBYIDRESPONSE']._serialized_start=315
  _globals['_GETINTEGRATIONBYIDRESPONSE']._serialized_end=412
  _globals['_CREATEINTEGRATIONAPPREQUEST']._serialized_start=415
  _globals['_CREATEINTEGRATIONAPPREQUEST']._serialized_end=752
  _globals['_CREATEINTEGRATIONAPPRESPONSE']._serialized_start=754
  _globals['_CREATEINTEGRATIONAPPRESPONSE']._serialized_end=853
  _globals['_DELETEINTEGRATIONAPPREQUEST']._serialized_start=855
  _globals['_DELETEINTEGRATIONAPPREQUEST']._serialized_end=900
  _globals['_DELETEINTEGRATIONAPPRESPONSE']._serialized_start=902
  _globals['_DELETEINTEGRATIONAPPRESPONSE']._serialized_end=932
  _globals['_APPSERVICE']._serialized_start=935
  _globals['_APPSERVICE']._serialized_end=1456
# @@protoc_insertion_point(module_scope)



import grpc


from .gen.admin.v1.integration_sso_pb2 import (
	GetWorkOsOrgRequest,
	GetWorkOsOrgResponse,
	UpdateWorkOsOrgRequest,
	UpdateWorkOsOrgResponse,
	GetSsoConnectionsRequest,
	GetSsoConnectionsResponse,
	DeleteConnectionRequest,
	DeleteConnectionResponse,
)

from .gen.admin.v1.integration_sso_pb2_grpc import SsoServiceStub
class SsoService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = SsoServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetWorkOsOrg(self, request: GetWorkOsOrgRequest) -> GetWorkOsOrgResponse:
		return self.stub.GetWorkOsOrg(request, metadata=self.headers)

	def UpdateWorkOsOrg(self, request: UpdateWorkOsOrgRequest) -> UpdateWorkOsOrgResponse:
		return self.stub.UpdateWorkOsOrg(request, metadata=self.headers)

	def GetSsoConnections(self, request: GetSsoConnectionsRequest) -> GetSsoConnectionsResponse:
		return self.stub.GetSsoConnections(request, metadata=self.headers)

	def DeleteConnection(self, request: DeleteConnectionRequest) -> DeleteConnectionResponse:
		return self.stub.DeleteConnection(request, metadata=self.headers)




from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateOrUpdateDefaultFieldEncryptionPolicyRequest(_message.Message):
    __slots__ = ["kms_key_id", "encryption_alg", "data_key_storage"]
    KMS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_ALG_FIELD_NUMBER: _ClassVar[int]
    DATA_KEY_STORAGE_FIELD_NUMBER: _ClassVar[int]
    kms_key_id: str
    encryption_alg: str
    data_key_storage: str
    def __init__(self, kms_key_id: _Optional[str] = ..., encryption_alg: _Optional[str] = ..., data_key_storage: _Optional[str] = ...) -> None: ...

class CreateOrUpdateDefaultFieldEncryptionPolicyResponse(_message.Message):
    __slots__ = ["default_field_encryption_policy"]
    DEFAULT_FIELD_ENCRYPTION_POLICY_FIELD_NUMBER: _ClassVar[int]
    default_field_encryption_policy: DefaultFieldEncryptionPolicy
    def __init__(self, default_field_encryption_policy: _Optional[_Union[DefaultFieldEncryptionPolicy, _Mapping]] = ...) -> None: ...

class GetDefaultFieldEncryptionPolicyRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDefaultFieldEncryptionPolicyResponse(_message.Message):
    __slots__ = ["default_field_encryption_policy"]
    DEFAULT_FIELD_ENCRYPTION_POLICY_FIELD_NUMBER: _ClassVar[int]
    default_field_encryption_policy: DefaultFieldEncryptionPolicy
    def __init__(self, default_field_encryption_policy: _Optional[_Union[DefaultFieldEncryptionPolicy, _Mapping]] = ...) -> None: ...

class DefaultFieldEncryptionPolicy(_message.Message):
    __slots__ = ["kms_key_id", "encryption_alg", "data_key_storage", "updated_at"]
    KMS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_ALG_FIELD_NUMBER: _ClassVar[int]
    DATA_KEY_STORAGE_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    kms_key_id: str
    encryption_alg: str
    data_key_storage: str
    updated_at: int
    def __init__(self, kms_key_id: _Optional[str] = ..., encryption_alg: _Optional[str] = ..., data_key_storage: _Optional[str] = ..., updated_at: _Optional[int] = ...) -> None: ...

class CreateFieldEncryptionRequest(_message.Message):
    __slots__ = ["path", "key_storage", "key_id", "alg", "datastore_id"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    KEY_STORAGE_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    path: str
    key_storage: str
    key_id: str
    alg: str
    datastore_id: str
    def __init__(self, path: _Optional[str] = ..., key_storage: _Optional[str] = ..., key_id: _Optional[str] = ..., alg: _Optional[str] = ..., datastore_id: _Optional[str] = ...) -> None: ...

class CreateFieldEncryptionResponse(_message.Message):
    __slots__ = ["field_encryption"]
    FIELD_ENCRYPTION_FIELD_NUMBER: _ClassVar[int]
    field_encryption: FieldEncryption
    def __init__(self, field_encryption: _Optional[_Union[FieldEncryption, _Mapping]] = ...) -> None: ...

class GetFieldEncryptionsByDatastoreRequest(_message.Message):
    __slots__ = ["datastore_id"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    def __init__(self, datastore_id: _Optional[str] = ...) -> None: ...

class GetFieldEncryptionsByDatastoreResponse(_message.Message):
    __slots__ = ["field_encryptions"]
    FIELD_ENCRYPTIONS_FIELD_NUMBER: _ClassVar[int]
    field_encryptions: _containers.RepeatedCompositeFieldContainer[FieldEncryption]
    def __init__(self, field_encryptions: _Optional[_Iterable[_Union[FieldEncryption, _Mapping]]] = ...) -> None: ...

class DeleteFieldEncryptionRequest(_message.Message):
    __slots__ = ["datastore_id", "field_encryption_id"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    FIELD_ENCRYPTION_ID_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    field_encryption_id: str
    def __init__(self, datastore_id: _Optional[str] = ..., field_encryption_id: _Optional[str] = ...) -> None: ...

class DeleteFieldEncryptionResponse(_message.Message):
    __slots__ = ["datastore_id"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    def __init__(self, datastore_id: _Optional[str] = ...) -> None: ...

class FieldEncryption(_message.Message):
    __slots__ = ["datastore_id", "name", "path", "key_storage", "key_id", "key_region", "alg"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    KEY_STORAGE_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_REGION_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    name: str
    path: str
    key_storage: str
    key_id: str
    key_region: str
    alg: str
    def __init__(self, datastore_id: _Optional[str] = ..., name: _Optional[str] = ..., path: _Optional[str] = ..., key_storage: _Optional[str] = ..., key_id: _Optional[str] = ..., key_region: _Optional[str] = ..., alg: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import sidecar_pb2 as admin_dot_v1_dot_sidecar__pb2


class SidecarServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSidecars = channel.unary_unary(
                '/admin.v1.SidecarService/ListSidecars',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsResponse.FromString,
                )
        self.GetSidecarVersions = channel.unary_unary(
                '/admin.v1.SidecarService/GetSidecarVersions',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsResponse.FromString,
                )
        self.CreateSidecar = channel.unary_unary(
                '/admin.v1.SidecarService/CreateSidecar',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarResponse.FromString,
                )
        self.GetSidecarById = channel.unary_unary(
                '/admin.v1.SidecarService/GetSidecarById',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdResponse.FromString,
                )
        self.GetSidecarTlsCertificateById = channel.unary_unary(
                '/admin.v1.SidecarService/GetSidecarTlsCertificateById',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdResponse.FromString,
                )
        self.UpdateSidecarName = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarName',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameResponse.FromString,
                )
        self.UpdateSidecarVersion = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarVersion',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionResponse.FromString,
                )
        self.UpdateSidecarFormalHostname = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarFormalHostname',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameResponse.FromString,
                )
        self.UpdateSidecarKmsDecryptPolicy = channel.unary_unary(
                '/admin.v1.SidecarService/UpdateSidecarKmsDecryptPolicy',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyResponse.FromString,
                )
        self.DeleteSidecar = channel.unary_unary(
                '/admin.v1.SidecarService/DeleteSidecar',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarResponse.FromString,
                )
        self.CreateSidecarDatastoreLink = channel.unary_unary(
                '/admin.v1.SidecarService/CreateSidecarDatastoreLink',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkResponse.FromString,
                )
        self.GetLinkById = channel.unary_unary(
                '/admin.v1.SidecarService/GetLinkById',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdResponse.FromString,
                )
        self.GetLinksBySidecarId = channel.unary_unary(
                '/admin.v1.SidecarService/GetLinksBySidecarId',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdResponse.FromString,
                )
        self.GetLinksByDatastoreId = channel.unary_unary(
                '/admin.v1.SidecarService/GetLinksByDatastoreId',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdResponse.FromString,
                )
        self.DeleteSidecarDatastoreLink = channel.unary_unary(
                '/admin.v1.SidecarService/DeleteSidecarDatastoreLink',
                request_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkResponse.FromString,
                )


class SidecarServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSidecars(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSidecarVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSidecar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSidecarById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSidecarTlsCertificateById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarFormalHostname(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSidecarKmsDecryptPolicy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSidecar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSidecarDatastoreLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinkById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinksBySidecarId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinksByDatastoreId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSidecarDatastoreLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SidecarServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSidecars': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSidecars,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.ListSidecarsResponse.SerializeToString,
            ),
            'GetSidecarVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSidecarVersions,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsResponse.SerializeToString,
            ),
            'CreateSidecar': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSidecar,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarResponse.SerializeToString,
            ),
            'GetSidecarById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSidecarById,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdResponse.SerializeToString,
            ),
            'GetSidecarTlsCertificateById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSidecarTlsCertificateById,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdResponse.SerializeToString,
            ),
            'UpdateSidecarName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarName,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameResponse.SerializeToString,
            ),
            'UpdateSidecarVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarVersion,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionResponse.SerializeToString,
            ),
            'UpdateSidecarFormalHostname': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarFormalHostname,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameResponse.SerializeToString,
            ),
            'UpdateSidecarKmsDecryptPolicy': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSidecarKmsDecryptPolicy,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyResponse.SerializeToString,
            ),
            'DeleteSidecar': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSidecar,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarResponse.SerializeToString,
            ),
            'CreateSidecarDatastoreLink': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSidecarDatastoreLink,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkResponse.SerializeToString,
            ),
            'GetLinkById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinkById,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinkByIdResponse.SerializeToString,
            ),
            'GetLinksBySidecarId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinksBySidecarId,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdResponse.SerializeToString,
            ),
            'GetLinksByDatastoreId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinksByDatastoreId,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdResponse.SerializeToString,
            ),
            'DeleteSidecarDatastoreLink': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSidecarDatastoreLink,
                    request_deserializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkRequest.FromString,
                    response_serializer=admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.SidecarService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SidecarService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSidecars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/ListSidecars',
            admin_dot_v1_dot_sidecar__pb2.ListSidecarsRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.ListSidecarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSidecarVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetSidecarVersions',
            admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetSidecarVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSidecar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/CreateSidecar',
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSidecarById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetSidecarById',
            admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetSidecarByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSidecarTlsCertificateById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetSidecarTlsCertificateById',
            admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetSidecarTlsCertificateByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarName',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarVersion',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarFormalHostname(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarFormalHostname',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarFormalHostnameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSidecarKmsDecryptPolicy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/UpdateSidecarKmsDecryptPolicy',
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.UpdateSidecarKmsDecryptPolicyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSidecar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/DeleteSidecar',
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSidecarDatastoreLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/CreateSidecarDatastoreLink',
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.CreateSidecarDatastoreLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLinkById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetLinkById',
            admin_dot_v1_dot_sidecar__pb2.GetLinkByIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetLinkByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLinksBySidecarId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetLinksBySidecarId',
            admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetLinksBySidecarIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLinksByDatastoreId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/GetLinksByDatastoreId',
            admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.GetLinksByDatastoreIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSidecarDatastoreLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/admin.v1.SidecarService/DeleteSidecarDatastoreLink',
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkRequest.SerializeToString,
            admin_dot_v1_dot_sidecar__pb2.DeleteSidecarDatastoreLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/types/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"admin/v1/types/v1/connection.proto\x12\x11\x61\x64min.v1.types.v1\"\x99\x03\n\nConnection\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12;\n\x06status\x18\x02 \x01(\x0e\x32#.admin.v1.types.v1.ConnectionStatusR\x06status\x12\x38\n\x05state\x18\x03 \x01(\x0e\x32\".admin.v1.types.v1.ConnectionStateR\x05state\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12J\n\x0f\x63onnection_type\x18\x05 \x01(\x0e\x32!.admin.v1.types.v1.ConnectionTypeR\x0e\x63onnectionType\x12\'\n\x0forganization_id\x18\x06 \x01(\tR\x0eorganizationId\x12=\n\x07\x64omains\x18\x07 \x03(\x0b\x32#.admin.v1.types.v1.ConnectionDomainR\x07\x64omains\x12\x1d\n\ncreated_at\x18\x08 \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\t \x01(\tR\tupdatedAt\":\n\x10\x43onnectionDomain\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain*\xf3\x07\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x43ONNECTION_TYPE_ADFS_SAML\x10\x01\x12\x1c\n\x18\x43ONNECTION_TYPE_ADP_OIDC\x10\x02\x12\x1e\n\x1a\x43ONNECTION_TYPE_AUTH0_SAML\x10\x03\x12\x1e\n\x1a\x43ONNECTION_TYPE_AZURE_SAML\x10\x04\x12\x1c\n\x18\x43ONNECTION_TYPE_CAS_SAML\x10\x05\x12#\n\x1f\x43ONNECTION_TYPE_CLOUDFLARE_SAML\x10\x06\x12#\n\x1f\x43ONNECTION_TYPE_CLASS_LINK_SAML\x10\x07\x12!\n\x1d\x43ONNECTION_TYPE_CYBERARK_SAML\x10\x08\x12\x1c\n\x18\x43ONNECTION_TYPE_DUO_SAML\x10\t\x12 \n\x1c\x43ONNECTION_TYPE_GENERIC_OIDC\x10\n\x12 \n\x1c\x43ONNECTION_TYPE_GENERIC_SAML\x10\x0b\x12 \n\x1c\x43ONNECTION_TYPE_GOOGLE_OAUTH\x10\x0c\x12\x1f\n\x1b\x43ONNECTION_TYPE_GOOGLE_SAML\x10\r\x12#\n\x1f\x43ONNECTION_TYPE_JUMP_CLOUD_SAML\x10\x0e\x12\x1e\n\x1a\x43ONNECTION_TYPE_MAGIC_LINK\x10\x0f\x12#\n\x1f\x43ONNECTION_TYPE_MICROSOFT_OAUTH\x10\x10\x12#\n\x1f\x43ONNECTION_TYPE_MINIORANGE_SAML\x10\x11\x12\x1e\n\x1a\x43ONNECTION_TYPE_NETIQ_SAML\x10\x12\x12\x1d\n\x19\x43ONNECTION_TYPE_OKTA_SAML\x10\x13\x12!\n\x1d\x43ONNECTION_TYPE_ONELOGIN_SAML\x10\x14\x12\x1f\n\x1b\x43ONNECTION_TYPE_ORACLE_SAML\x10\x15\x12&\n\"CONNECTION_TYPE_PING_FEDERATE_SAML\x10\x16\x12!\n\x1d\x43ONNECTION_TYPE_PING_ONE_SAML\x10\x17\x12!\n\x1d\x43ONNECTION_TYPE_RIPPLING_SAML\x10\x18\x12#\n\x1f\x43ONNECTION_TYPE_SALESFORCE_SAML\x10\x19\x12#\n\x1f\x43ONNECTION_TYPE_SHIBBOLETH_SAML\x10\x1a\x12(\n$CONNECTION_TYPE_SIMPLE_SAML_PHP_SAML\x10\x1b\x12\x1f\n\x1b\x43ONNECTION_TYPE_VMWARE_SAML\x10\x1c*s\n\x10\x43onnectionStatus\x12!\n\x1d\x43ONNECTION_STATUS_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONNECTION_STATUS_LINKED\x10\x01\x12\x1e\n\x1a\x43ONNECTION_STATUS_UNLINKED\x10\x02*\x8b\x01\n\x0f\x43onnectionState\x12 \n\x1c\x43ONNECTION_STATE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x43ONNECTION_STATE_DRAFT\x10\x01\x12\x1b\n\x17\x43ONNECTION_STATE_ACTIVE\x10\x02\x12\x1d\n\x19\x43ONNECTION_STATE_INACTIVE\x10\x03\x42\xe2\x01\n\x15\x63om.admin.v1.types.v1B\x0f\x43onnectionProtoP\x01ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.connection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\017ConnectionProtoP\001ZQgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_CONNECTIONTYPE']._serialized_start=530
  _globals['_CONNECTIONTYPE']._serialized_end=1541
  _globals['_CONNECTIONSTATUS']._serialized_start=1543
  _globals['_CONNECTIONSTATUS']._serialized_end=1658
  _globals['_CONNECTIONSTATE']._serialized_start=1661
  _globals['_CONNECTIONSTATE']._serialized_end=1800
  _globals['_CONNECTION']._serialized_start=58
  _globals['_CONNECTION']._serialized_end=467
  _globals['_CONNECTIONDOMAIN']._serialized_start=469
  _globals['_CONNECTIONDOMAIN']._serialized_end=527
# @@protoc_insertion_point(module_scope)



from .types.v1 import domain_pb2 as _domain_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetInventoryFlatOldRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ColumnOld(_message.Message):
    __slots__ = ["created_at", "updated_at", "datastore_id", "datastore_name", "path", "table_physical_id", "table_attribute_number", "name", "alias", "table_path", "data_label", "data_type", "data_type_oid", "data_label_locked_for_sidecar", "tags", "encrypted"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TABLE_PHYSICAL_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_OID_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_LOCKED_FOR_SIDECAR_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    updated_at: int
    datastore_id: str
    datastore_name: str
    path: str
    table_physical_id: str
    table_attribute_number: int
    name: str
    alias: str
    table_path: str
    data_label: str
    data_type: str
    data_type_oid: int
    data_label_locked_for_sidecar: bool
    tags: _containers.RepeatedScalarFieldContainer[str]
    encrypted: bool
    def __init__(self, created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., path: _Optional[str] = ..., table_physical_id: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., name: _Optional[str] = ..., alias: _Optional[str] = ..., table_path: _Optional[str] = ..., data_label: _Optional[str] = ..., data_type: _Optional[str] = ..., data_type_oid: _Optional[int] = ..., data_label_locked_for_sidecar: bool = ..., tags: _Optional[_Iterable[str]] = ..., encrypted: bool = ...) -> None: ...

class GetInventoryFlatOldResponse(_message.Message):
    __slots__ = ["inventory"]
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[ColumnOld]
    def __init__(self, inventory: _Optional[_Iterable[_Union[ColumnOld, _Mapping]]] = ...) -> None: ...

class UpdateColumnFieldEncryptionRequest(_message.Message):
    __slots__ = ["datastore_id", "path", "encryption_key_storage", "encryption_key_id", "encryption_algorithm", "encrypt_existing_data"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_KEY_STORAGE_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    ENCRYPT_EXISTING_DATA_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    encryption_key_storage: str
    encryption_key_id: str
    encryption_algorithm: str
    encrypt_existing_data: bool
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., encryption_key_storage: _Optional[str] = ..., encryption_key_id: _Optional[str] = ..., encryption_algorithm: _Optional[str] = ..., encrypt_existing_data: bool = ...) -> None: ...

class UpdateColumnFieldEncryptionResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetInventoryObjectRequest(_message.Message):
    __slots__ = ["datastore_id", "path"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...

class GetInventoryObjectResponse(_message.Message):
    __slots__ = ["column"]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    column: Column
    def __init__(self, column: _Optional[_Union[Column, _Mapping]] = ...) -> None: ...

class GetInventoryHierarchicalRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetInventoryHierarchicalResponse(_message.Message):
    __slots__ = ["inventory"]
    class Datastore(_message.Message):
        __slots__ = ["id", "name", "technology", "dbs"]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
        DBS_FIELD_NUMBER: _ClassVar[int]
        id: str
        name: str
        technology: str
        dbs: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Db]
        def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., technology: _Optional[str] = ..., dbs: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Db, _Mapping]]] = ...) -> None: ...
    class Db(_message.Message):
        __slots__ = ["path", "name", "datastore_id", "schemas", "tables"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
        SCHEMAS_FIELD_NUMBER: _ClassVar[int]
        TABLES_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        datastore_id: str
        schemas: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Schema]
        tables: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Table]
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., datastore_id: _Optional[str] = ..., schemas: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Schema, _Mapping]]] = ..., tables: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Table, _Mapping]]] = ...) -> None: ...
    class Schema(_message.Message):
        __slots__ = ["path", "name", "db_path", "tables"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        DB_PATH_FIELD_NUMBER: _ClassVar[int]
        TABLES_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        db_path: str
        tables: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Table]
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., db_path: _Optional[str] = ..., tables: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Table, _Mapping]]] = ...) -> None: ...
    class Table(_message.Message):
        __slots__ = ["path", "name", "db_path", "schema_path", "columns"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        DB_PATH_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
        COLUMNS_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        db_path: str
        schema_path: str
        columns: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Column]
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., db_path: _Optional[str] = ..., schema_path: _Optional[str] = ..., columns: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Column, _Mapping]]] = ...) -> None: ...
    class Column(_message.Message):
        __slots__ = ["path", "name", "table_path"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        table_path: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., table_path: _Optional[str] = ...) -> None: ...
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[GetInventoryHierarchicalResponse.Datastore]
    def __init__(self, inventory: _Optional[_Iterable[_Union[GetInventoryHierarchicalResponse.Datastore, _Mapping]]] = ...) -> None: ...

class GetInventoryRequest(_message.Message):
    __slots__ = ["limit", "cursor", "order", "path", "excluded_paths", "included_objects"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    INCLUDED_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    order: str
    path: str
    excluded_paths: _containers.RepeatedScalarFieldContainer[str]
    included_objects: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., order: _Optional[str] = ..., path: _Optional[str] = ..., excluded_paths: _Optional[_Iterable[str]] = ..., included_objects: _Optional[_Iterable[str]] = ...) -> None: ...

class GetInventoryResponse(_message.Message):
    __slots__ = ["inventory", "list_metadata"]
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[InventoryObject]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, inventory: _Optional[_Iterable[_Union[InventoryObject, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class GetInventoryFlatRequest(_message.Message):
    __slots__ = ["limit", "after", "before", "order"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    after: str
    before: str
    order: str
    def __init__(self, limit: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ..., order: _Optional[str] = ...) -> None: ...

class Column(_message.Message):
    __slots__ = ["created_at", "updated_at", "datastore_id", "datastore_name", "path", "table_physical_id", "table_attribute_number", "name", "alias", "table_path", "data_label", "data_type", "data_type_oid", "data_label_locked_for_sidecar", "tags", "encrypted", "id"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TABLE_PHYSICAL_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ALIAS_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_OID_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_LOCKED_FOR_SIDECAR_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    updated_at: int
    datastore_id: str
    datastore_name: str
    path: str
    table_physical_id: str
    table_attribute_number: int
    name: str
    alias: str
    table_path: str
    data_label: str
    data_type: str
    data_type_oid: int
    data_label_locked_for_sidecar: bool
    tags: _containers.RepeatedScalarFieldContainer[str]
    encrypted: bool
    id: str
    def __init__(self, created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., path: _Optional[str] = ..., table_physical_id: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., name: _Optional[str] = ..., alias: _Optional[str] = ..., table_path: _Optional[str] = ..., data_label: _Optional[str] = ..., data_type: _Optional[str] = ..., data_type_oid: _Optional[int] = ..., data_label_locked_for_sidecar: bool = ..., tags: _Optional[_Iterable[str]] = ..., encrypted: bool = ..., id: _Optional[str] = ...) -> None: ...

class Ds(_message.Message):
    __slots__ = ["id", "name", "technology", "dbs"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    DBS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    technology: str
    dbs: _containers.RepeatedCompositeFieldContainer[Db]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., technology: _Optional[str] = ..., dbs: _Optional[_Iterable[_Union[Db, _Mapping]]] = ...) -> None: ...

class Db(_message.Message):
    __slots__ = ["path", "name", "datastore_id", "schemas", "tables", "id"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    TABLES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    path: str
    name: str
    datastore_id: str
    schemas: _containers.RepeatedCompositeFieldContainer[Schema]
    tables: _containers.RepeatedCompositeFieldContainer[Table]
    id: str
    def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., datastore_id: _Optional[str] = ..., schemas: _Optional[_Iterable[_Union[Schema, _Mapping]]] = ..., tables: _Optional[_Iterable[_Union[Table, _Mapping]]] = ..., id: _Optional[str] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ["path", "name", "db_path", "tables", "id", "datastore_id"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DB_PATH_FIELD_NUMBER: _ClassVar[int]
    TABLES_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    path: str
    name: str
    db_path: str
    tables: _containers.RepeatedCompositeFieldContainer[Table]
    id: str
    datastore_id: str
    def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., db_path: _Optional[str] = ..., tables: _Optional[_Iterable[_Union[Table, _Mapping]]] = ..., id: _Optional[str] = ..., datastore_id: _Optional[str] = ...) -> None: ...

class Table(_message.Message):
    __slots__ = ["path", "name", "db_path", "schema_path", "columns", "id", "datastore_id"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DB_PATH_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    path: str
    name: str
    db_path: str
    schema_path: str
    columns: _containers.RepeatedCompositeFieldContainer[Column]
    id: str
    datastore_id: str
    def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., db_path: _Optional[str] = ..., schema_path: _Optional[str] = ..., columns: _Optional[_Iterable[_Union[Column, _Mapping]]] = ..., id: _Optional[str] = ..., datastore_id: _Optional[str] = ...) -> None: ...

class SubColumn(_message.Message):
    __slots__ = ["created_at", "updated_at", "datastore_id", "datastore_name", "path", "name", "table_path", "data_label", "data_type", "data_type_oid", "data_label_locked_for_sidecar", "tags", "encrypted", "id"]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_TYPE_OID_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_LOCKED_FOR_SIDECAR_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    created_at: int
    updated_at: int
    datastore_id: str
    datastore_name: str
    path: str
    name: str
    table_path: str
    data_label: str
    data_type: str
    data_type_oid: int
    data_label_locked_for_sidecar: bool
    tags: _containers.RepeatedScalarFieldContainer[str]
    encrypted: bool
    id: str
    def __init__(self, created_at: _Optional[int] = ..., updated_at: _Optional[int] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., path: _Optional[str] = ..., name: _Optional[str] = ..., table_path: _Optional[str] = ..., data_label: _Optional[str] = ..., data_type: _Optional[str] = ..., data_type_oid: _Optional[int] = ..., data_label_locked_for_sidecar: bool = ..., tags: _Optional[_Iterable[str]] = ..., encrypted: bool = ..., id: _Optional[str] = ...) -> None: ...

class InventoryObject(_message.Message):
    __slots__ = ["datastore", "db", "schema", "table", "column", "sub_column"]
    DATASTORE_FIELD_NUMBER: _ClassVar[int]
    DB_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    SUB_COLUMN_FIELD_NUMBER: _ClassVar[int]
    datastore: Ds
    db: Db
    schema: Schema
    table: Table
    column: Column
    sub_column: SubColumn
    def __init__(self, datastore: _Optional[_Union[Ds, _Mapping]] = ..., db: _Optional[_Union[Db, _Mapping]] = ..., schema: _Optional[_Union[Schema, _Mapping]] = ..., table: _Optional[_Union[Table, _Mapping]] = ..., column: _Optional[_Union[Column, _Mapping]] = ..., sub_column: _Optional[_Union[SubColumn, _Mapping]] = ...) -> None: ...

class GetInventoryFlatResponse(_message.Message):
    __slots__ = ["inventory", "list_metadata"]
    INVENTORY_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    inventory: _containers.RepeatedCompositeFieldContainer[InventoryObject]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, inventory: _Optional[_Iterable[_Union[InventoryObject, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class UpdateColumnLockStatusRequest(_message.Message):
    __slots__ = ["datastore_id", "path", "validated"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    VALIDATED_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    validated: bool
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., validated: bool = ...) -> None: ...

class UpdateColumnLockStatusResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateColumnDataLabelRequest(_message.Message):
    __slots__ = ["datastore_id", "path", "data_label"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    data_label: str
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., data_label: _Optional[str] = ...) -> None: ...

class UpdateColumnDataLabelResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class CreateInventoryObjectRequest(_message.Message):
    __slots__ = ["datastore_id", "object_type", "db", "schema", "table", "column", "sub_column"]
    class Db(_message.Message):
        __slots__ = ["path", "name"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    class Schema(_message.Message):
        __slots__ = ["path", "name"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    class Table(_message.Message):
        __slots__ = ["path", "name"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...
    class Column(_message.Message):
        __slots__ = ["path", "name", "data_type"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        data_type: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., data_type: _Optional[str] = ...) -> None: ...
    class SubColumn(_message.Message):
        __slots__ = ["path", "name", "sub_type"]
        PATH_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        SUB_TYPE_FIELD_NUMBER: _ClassVar[int]
        path: str
        name: str
        sub_type: str
        def __init__(self, path: _Optional[str] = ..., name: _Optional[str] = ..., sub_type: _Optional[str] = ...) -> None: ...
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    DB_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    SUB_COLUMN_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    object_type: str
    db: CreateInventoryObjectRequest.Db
    schema: CreateInventoryObjectRequest.Schema
    table: CreateInventoryObjectRequest.Table
    column: CreateInventoryObjectRequest.Column
    sub_column: CreateInventoryObjectRequest.SubColumn
    def __init__(self, datastore_id: _Optional[str] = ..., object_type: _Optional[str] = ..., db: _Optional[_Union[CreateInventoryObjectRequest.Db, _Mapping]] = ..., schema: _Optional[_Union[CreateInventoryObjectRequest.Schema, _Mapping]] = ..., table: _Optional[_Union[CreateInventoryObjectRequest.Table, _Mapping]] = ..., column: _Optional[_Union[CreateInventoryObjectRequest.Column, _Mapping]] = ..., sub_column: _Optional[_Union[CreateInventoryObjectRequest.SubColumn, _Mapping]] = ...) -> None: ...

class CreateInventoryObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeleteInventoryObjectRequest(_message.Message):
    __slots__ = ["datastore_id", "path"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ...) -> None: ...

class DeleteInventoryObjectResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class Tag(_message.Message):
    __slots__ = ["id", "name", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateInventoryTagRequest(_message.Message):
    __slots__ = ["name"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateInventoryTagResponse(_message.Message):
    __slots__ = ["tag"]
    TAG_FIELD_NUMBER: _ClassVar[int]
    tag: Tag
    def __init__(self, tag: _Optional[_Union[Tag, _Mapping]] = ...) -> None: ...

class GetInventoryTagsRequest(_message.Message):
    __slots__ = ["limit", "after", "before", "order"]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    after: str
    before: str
    order: str
    def __init__(self, limit: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ..., order: _Optional[str] = ...) -> None: ...

class GetInventoryTagsResponse(_message.Message):
    __slots__ = ["tags", "list_metadata"]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class UpdateInventoryObjectTagsRequest(_message.Message):
    __slots__ = ["datastore_id", "path", "tags"]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateInventoryObjectTagsResponse(_message.Message):
    __slots__ = ["object"]
    class InventoryObject(_message.Message):
        __slots__ = ["datastore_id", "type", "path", "db_path", "table_path", "schema_path", "table_attribute_number", "data_type", "data_label", "updated_at", "created_at", "data_store_name", "name", "validated", "tags"]
        DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        DB_PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_ATTRIBUTE_NUMBER_FIELD_NUMBER: _ClassVar[int]
        DATA_TYPE_FIELD_NUMBER: _ClassVar[int]
        DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
        UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
        CREATED_AT_FIELD_NUMBER: _ClassVar[int]
        DATA_STORE_NAME_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        VALIDATED_FIELD_NUMBER: _ClassVar[int]
        TAGS_FIELD_NUMBER: _ClassVar[int]
        datastore_id: str
        type: str
        path: str
        db_path: str
        table_path: str
        schema_path: str
        table_attribute_number: int
        data_type: str
        data_label: str
        updated_at: int
        created_at: int
        data_store_name: str
        name: str
        validated: bool
        tags: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, datastore_id: _Optional[str] = ..., type: _Optional[str] = ..., path: _Optional[str] = ..., db_path: _Optional[str] = ..., table_path: _Optional[str] = ..., schema_path: _Optional[str] = ..., table_attribute_number: _Optional[int] = ..., data_type: _Optional[str] = ..., data_label: _Optional[str] = ..., updated_at: _Optional[int] = ..., created_at: _Optional[int] = ..., data_store_name: _Optional[str] = ..., name: _Optional[str] = ..., validated: bool = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...
    OBJECT_FIELD_NUMBER: _ClassVar[int]
    object: UpdateInventoryObjectTagsResponse.InventoryObject
    def __init__(self, object: _Optional[_Union[UpdateInventoryObjectTagsResponse.InventoryObject, _Mapping]] = ...) -> None: ...

class DeleteInventoryTagRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteInventoryTagResponse(_message.Message):
    __slots__ = ["tags"]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    def __init__(self, tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ...) -> None: ...

class GetInventoryMetricsRequest(_message.Message):
    __slots__ = ["user_id", "datastore_id", "path", "object_type", "timeframe"]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    OBJECT_TYPE_FIELD_NUMBER: _ClassVar[int]
    TIMEFRAME_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    datastore_id: str
    path: str
    object_type: str
    timeframe: str
    def __init__(self, user_id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., object_type: _Optional[str] = ..., timeframe: _Optional[str] = ...) -> None: ...

class GetInventoryMetricsResponse(_message.Message):
    __slots__ = ["metrics"]
    class Metric(_message.Message):
        __slots__ = ["name", "path", "column_name", "column_path", "table_name", "table_path", "schema_name", "schema_path", "db_name", "user_id", "db_user", "end_user_id", "end_user_db_username", "app_type", "org_id", "datastore_id", "datastore_name", "ts", "counter", "returned_rows", "ip_address", "data_label", "data_labels", "datastore_technology", "bucket"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        COLUMN_NAME_FIELD_NUMBER: _ClassVar[int]
        COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
        TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
        TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
        SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
        DB_NAME_FIELD_NUMBER: _ClassVar[int]
        USER_ID_FIELD_NUMBER: _ClassVar[int]
        DB_USER_FIELD_NUMBER: _ClassVar[int]
        END_USER_ID_FIELD_NUMBER: _ClassVar[int]
        END_USER_DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
        APP_TYPE_FIELD_NUMBER: _ClassVar[int]
        ORG_ID_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
        TS_FIELD_NUMBER: _ClassVar[int]
        COUNTER_FIELD_NUMBER: _ClassVar[int]
        RETURNED_ROWS_FIELD_NUMBER: _ClassVar[int]
        IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
        DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
        DATA_LABELS_FIELD_NUMBER: _ClassVar[int]
        DATASTORE_TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
        BUCKET_FIELD_NUMBER: _ClassVar[int]
        name: str
        path: str
        column_name: str
        column_path: str
        table_name: str
        table_path: str
        schema_name: str
        schema_path: str
        db_name: str
        user_id: str
        db_user: str
        end_user_id: str
        end_user_db_username: str
        app_type: str
        org_id: str
        datastore_id: str
        datastore_name: str
        ts: str
        counter: int
        returned_rows: int
        ip_address: str
        data_label: str
        data_labels: _containers.RepeatedScalarFieldContainer[str]
        datastore_technology: str
        bucket: str
        def __init__(self, name: _Optional[str] = ..., path: _Optional[str] = ..., column_name: _Optional[str] = ..., column_path: _Optional[str] = ..., table_name: _Optional[str] = ..., table_path: _Optional[str] = ..., schema_name: _Optional[str] = ..., schema_path: _Optional[str] = ..., db_name: _Optional[str] = ..., user_id: _Optional[str] = ..., db_user: _Optional[str] = ..., end_user_id: _Optional[str] = ..., end_user_db_username: _Optional[str] = ..., app_type: _Optional[str] = ..., org_id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., ts: _Optional[str] = ..., counter: _Optional[int] = ..., returned_rows: _Optional[int] = ..., ip_address: _Optional[str] = ..., data_label: _Optional[str] = ..., data_labels: _Optional[_Iterable[str]] = ..., datastore_technology: _Optional[str] = ..., bucket: _Optional[str] = ...) -> None: ...
    METRICS_FIELD_NUMBER: _ClassVar[int]
    metrics: _containers.RepeatedCompositeFieldContainer[GetInventoryMetricsResponse.Metric]
    def __init__(self, metrics: _Optional[_Iterable[_Union[GetInventoryMetricsResponse.Metric, _Mapping]]] = ...) -> None: ...

class CreateDataDomainRequest(_message.Message):
    __slots__ = ["name", "description", "owners", "excluded_paths", "included_paths"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    INCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    owners: _containers.RepeatedCompositeFieldContainer[_domain_pb2.Owner]
    excluded_paths: _containers.RepeatedScalarFieldContainer[str]
    included_paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., owners: _Optional[_Iterable[_Union[_domain_pb2.Owner, _Mapping]]] = ..., excluded_paths: _Optional[_Iterable[str]] = ..., included_paths: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateDataDomainResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDataDomainsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDataDomainsResponse(_message.Message):
    __slots__ = ["domains"]
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    domains: _containers.RepeatedCompositeFieldContainer[_domain_pb2.Domain]
    def __init__(self, domains: _Optional[_Iterable[_Union[_domain_pb2.Domain, _Mapping]]] = ...) -> None: ...

class GetDataDomainByIdRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDataDomainByIdResponse(_message.Message):
    __slots__ = ["domain"]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    domain: _domain_pb2.Domain
    def __init__(self, domain: _Optional[_Union[_domain_pb2.Domain, _Mapping]] = ...) -> None: ...

class UpdateDataDomainRequest(_message.Message):
    __slots__ = ["id", "name", "description", "owners", "excluded_paths", "included_paths"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    EXCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    INCLUDED_PATHS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    owners: _containers.RepeatedCompositeFieldContainer[_domain_pb2.Owner]
    excluded_paths: _containers.RepeatedScalarFieldContainer[str]
    included_paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., owners: _Optional[_Iterable[_Union[_domain_pb2.Owner, _Mapping]]] = ..., excluded_paths: _Optional[_Iterable[str]] = ..., included_paths: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateDataDomainResponse(_message.Message):
    __slots__ = ["domain"]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    domain: _domain_pb2.Domain
    def __init__(self, domain: _Optional[_Union[_domain_pb2.Domain, _Mapping]] = ...) -> None: ...

class DeleteDataDomainRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteDataDomainResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import search_pb2 as admin_dot_v1_dot_types_dot_v1_dot_search__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61\x64min/v1/search.proto\x12\x08\x61\x64min.v1\x1a\x1e\x61\x64min/v1/types/v1/search.proto\"\xa6\x01\n\rSearchRequest\x12\x1f\n\x0bobject_type\x18\x01 \x01(\tR\nobjectType\x12\x14\n\x05query\x18\x02 \x01(\tR\x05query\x12\x1b\n\tfilter_by\x18\x03 \x01(\tR\x08\x66ilterBy\x12\x17\n\x07sort_by\x18\x04 \x01(\tR\x06sortBy\x12\x12\n\x04page\x18\x05 \x01(\x05R\x04page\x12\x14\n\x05limit\x18\x06 \x01(\x05R\x05limit\"\x98\x04\n\x0eSearchResponse\x12\x33\n\x05users\x18\x01 \x01(\x0b\x32\x1b.admin.v1.WrappedSearchUserH\x00R\x05users\x12\x36\n\x06groups\x18\x02 \x01(\x0b\x32\x1c.admin.v1.WrappedSearchGroupH\x00R\x06groups\x12;\n\x08policies\x18\x03 \x01(\x0b\x32\x1d.admin.v1.WrappedSearchPolicyH\x00R\x08policies\x12\x42\n\ndatastores\x18\x04 \x01(\x0b\x32 .admin.v1.WrappedSearchDatastoreH\x00R\ndatastores\x12<\n\x08sidecars\x18\x05 \x01(\x0b\x32\x1e.admin.v1.WrappedSearchSidecarH\x00R\x08sidecars\x12\x44\n\x0binventories\x18\x06 \x01(\x0b\x32 .admin.v1.WrappedSearchInventoryH\x00R\x0binventories\x12\x14\n\x05\x66ound\x18\x07 \x01(\x05R\x05\x66ound\x12\x12\n\x04page\x18\x08 \x01(\x05R\x04page\x12\x15\n\x06out_of\x18\t \x01(\x05R\x05outOf\x12$\n\x0esearch_time_ms\x18\n \x01(\x05R\x0csearchTimeMs\x12#\n\rsearch_cutoff\x18\x0b \x01(\x08R\x0csearchCutoffB\x08\n\x06result\"F\n\x11WrappedSearchUser\x12\x31\n\x04user\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.SearchUserR\x04user\"J\n\x12WrappedSearchGroup\x12\x34\n\x05group\x18\x01 \x03(\x0b\x32\x1e.admin.v1.types.v1.SearchGroupR\x05group\"N\n\x13WrappedSearchPolicy\x12\x37\n\x06policy\x18\x01 \x03(\x0b\x32\x1f.admin.v1.types.v1.SearchPolicyR\x06policy\"Z\n\x16WrappedSearchDatastore\x12@\n\tdatastore\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.SearchDatastoreR\tdatastore\"R\n\x14WrappedSearchSidecar\x12:\n\x07sidecar\x18\x01 \x03(\x0b\x32 .admin.v1.types.v1.SearchSidecarR\x07sidecar\"Z\n\x16WrappedSearchInventory\x12@\n\tinventory\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.SearchInventoryR\tinventory2N\n\rSearchService\x12=\n\x06Search\x12\x17.admin.v1.SearchRequest\x1a\x18.admin.v1.SearchResponse\"\x00\x42\xa6\x01\n\x0c\x63om.admin.v1B\x0bSearchProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.search_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\013SearchProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_SEARCHREQUEST']._serialized_start=68
  _globals['_SEARCHREQUEST']._serialized_end=234
  _globals['_SEARCHRESPONSE']._serialized_start=237
  _globals['_SEARCHRESPONSE']._serialized_end=773
  _globals['_WRAPPEDSEARCHUSER']._serialized_start=775
  _globals['_WRAPPEDSEARCHUSER']._serialized_end=845
  _globals['_WRAPPEDSEARCHGROUP']._serialized_start=847
  _globals['_WRAPPEDSEARCHGROUP']._serialized_end=921
  _globals['_WRAPPEDSEARCHPOLICY']._serialized_start=923
  _globals['_WRAPPEDSEARCHPOLICY']._serialized_end=1001
  _globals['_WRAPPEDSEARCHDATASTORE']._serialized_start=1003
  _globals['_WRAPPEDSEARCHDATASTORE']._serialized_end=1093
  _globals['_WRAPPEDSEARCHSIDECAR']._serialized_start=1095
  _globals['_WRAPPEDSEARCHSIDECAR']._serialized_end=1177
  _globals['_WRAPPEDSEARCHINVENTORY']._serialized_start=1179
  _globals['_WRAPPEDSEARCHINVENTORY']._serialized_end=1269
  _globals['_SEARCHSERVICE']._serialized_start=1271
  _globals['_SEARCHSERVICE']._serialized_end=1349
# @@protoc_insertion_point(module_scope)
